import os, glob, random, time, marshal

import pygame
from pygame.locals import *

pygame.init()

# import after pygame.init()
from game import Game, Quit

vera = pygame.font.Font('data/Vera.ttf', 64)
vera_small = pygame.font.Font('data/Vera.ttf', 24)

levels = glob.glob(os.path.join('data', 'level*.tga'))
levels.sort()

MENU_MAIN = 1
MENU_WIN = 2
MENU_LOSE = 3

class Menu:
    def __init__(self):
        self.screen = pygame.display.set_mode((800, 600), DOUBLEBUF)
        #self.screen = pygame.display.set_mode((800, 600), DOUBLEBUF|FULLSCREEN)
        self.menu_img = pygame.image.load('data/menu.png').convert_alpha(
            self.screen)
        self.menu_win = pygame.image.load('data/menu-win.png').convert_alpha(
            self.screen)
        self.menu_lose = pygame.image.load('data/menu-lose.png').convert_alpha(
            self.screen)
        self.menu_eyes = pygame.image.load('data/menu-eyes.png').convert_alpha(
            self.screen)

    def main(self):
        self.menu_item = 0
        self.menu_screen = MENU_MAIN
        self.renderMenu()

        self.exit = False
        while not self.exit:
            event = pygame.event.wait()
            if self.events(event):
                break
            self.renderMenu()
            pygame.display.flip()

    def events(self, event):
        while event.type != NOEVENT:
            if event.type == NOEVENT:
                pass
            elif event.type == QUIT:
                return True
            elif event.type == KEYDOWN:
                if self.menu_screen != MENU_MAIN:
                    self.menu_screen = MENU_MAIN
                    return False
                if event.key == K_UP:
                    self.menu_item -= 1
                    if self.menu_item < 0: self.menu_item += 2
                elif event.key == K_DOWN:
                    self.menu_item = (self.menu_item + 1)%2
                elif event.key == K_RETURN:
                    self.menu_actions[self.menu_item](self)
                elif event.key == K_ESCAPE:
                    return True

            event = pygame.event.poll()
        return False

    def renderMenu(self):
        if self.menu_screen == MENU_WIN:
            self.screen.blit(self.menu_win, (0,0))
        elif self.menu_screen == MENU_LOSE:
            self.screen.blit(self.menu_lose, (0,0))
        else:
            self.screen.blit(self.menu_img, (0,0))
            self.screen.blit(self.menu_eyes, (620, 425),
                    (random.randint(0,3)*160, 0, 160, 160))

            for i, item in enumerate(['Play Game', 'Quit Game']):
                if i == self.menu_item:
                    color = (255, 100, 100)
                else:
                    color = (150, 50, 50)
                text = vera.render(item, 1, color, (0, 0, 0))
                r = text.get_rect()
                r.center = (400, 300 + 100*i)
                self.screen.blit(text, r.topleft)

    def runGame(self):
        level = 0
        while 1:
            file = levels[level]
            f = open(file.replace('.tga', '.txt'))
            lines = f.readlines()
            f.close()
            try:
                self.showText(lines)
                ts = time.time()
                win = Game().main(self.screen, levels[level])
            except Quit:
                return
            if win:
                self.handleTime(lines[0], time.time() - ts)
                level += 1
                if level == len(levels):
                    self.menu_screen = MENU_WIN
                    return
            else:
                self.menu_screen = MENU_LOSE
                return

    def handleTime(self, level, time):
        self.screen.fill((0,0,0))
        if os.path.exists('times.mar'):
            f = open('times.mar')
            times = marshal.load(f)
            f.close()
        else:
            times = {}
        if times.has_key(level):
            if time < times[level]:
                times[level] = time
                text = 'You beat the record!'
            else:
                text = "You weren't fast enough to beat the record."
        else:
            times[level] = time
            text = 'New record time saved.'

        text += '''

You finished that level in %.2f seconds.




Press any key to continue'''%time
        f = open('times.mar', 'wb')
        marshal.dump(times, f)
        f.close()
        self.showText(text.splitlines())

    def showText(self, lines):
        self.screen.fill((0,0,0))
        for i, line in enumerate(lines):
            line = vera_small.render(line.strip(), 1, (200,200,200), (0,0,0))
            self.screen.blit(line, (10, 30*i))
        pygame.display.flip()
        while 1:
            event = pygame.event.wait()
            if event.type == QUIT:
                raise Quit
            elif event.type == KEYDOWN:
                return


    def quitGame(self):
        self.exit = True

    menu_actions = [
        runGame,
        quitGame,
    ]


if __name__ == '__main__':
    Menu().main()

